@@ -1,4 +1,4 @@
-import Format
+from FPE import Format
 from numpy import arange
 
 RADIX_DEFAULT = 10
